@@ -75,7 +75,7 @@ def ClientMethod(
                 FlaskManager.validateArgs(args, requestClass, resourceInstanceMethod)
                 completeResponse = resourceInstanceMethod(*args, **kwargs)
                 ###- This simple client cannot handle headers or anything this much elegant
-                if ObjectHelper.isTuple() and 0 < len(completeResponse):
+                if ObjectHelper.isTuple(completeResponse) and 0 < len(completeResponse):
                     completeResponse = completeResponse[1]
             except Exception as exception :
                 log.log(innerResourceInstanceMethod, 'Failure at client method execution', exception=exception, muteStackTrace=True)
